Documentation
¶
Index ¶
Constants ¶
const ENUMS = 7
Ensure that ENUMS is equal to the amount of Sector Enums
Variables ¶
This section is empty.
Functions ¶
func GetMarketPrice ¶
GetMarketPrice() -> Get's current price of stocks
Types ¶
type SectorBase ¶
type SectorFunc ¶
type SectorFunc interface {
// Ensure that all the functions are of equal length to (iota) Enums
String() string
}
type Tranche ¶
type Tranche struct {
SectorBase
Percentage float32
}
Click to show internal directories.
Click to hide internal directories.